First Time Setup — Toyz 0.0.0 documentation

# First Time Setup

Once you have installed toyz (see install ) you are ready to setup your local toyz application.

Note

You can have more than one instance of a toyz application installed on the same system.

From any directory type:

    >>>toyz

and you will be promped to setup toyz for the fist time.

Warning

The default directory is in yout python library but it is not advised to install toyz there. If you choose to install here you will lose all of your settings and users when you update or re-install toyz.

A more recomended install directory would be `~/toyz` .

Once the first time setup has been completed the application will start and you will be given a port that is running the application.